@@ -4,19 +4,6 @@
 #include "Definitions.h"
 
 namespace libcalculus {
-    template<typename T>
-    struct Traits {
-    public:
-        static constexpr REAL tol = [] {
-            if constexpr (std::is_same<T, REAL>::value)
-                return 1e-6;
-            else if constexpr (std::is_same<T, COMPLEX>::value)
-                return 1e-6;
-        }();
-
-        inline static bool close(T const a, T const b, REAL const tol=Traits<T>::tol) noexcept { return std::abs(a - b) < tol; }
-    };
-
     template<typename Dom>
     class CComparison {
     public:
